# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class DocumentWithoutSegments(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'project_id': 'int',
        'srclang': 'str',
        'trglang': 'str',
        'name': 'str',
        'import_in_progress': 'bool',
        'import_succeeded': 'bool',
        'import_error_message': 'str',
        'export_in_progress': 'bool',
        'export_succeeded': 'bool',
        'export_error_message': 'str',
        'is_pretranslating': 'bool',
        'status': 'DocumentWithoutSegmentsStatus',
        'translator_email': 'str',
        'reviewer_email': 'str',
        'created_at': 'int',
        'updated_at': 'int'
    }

    attribute_map = {
        'id': 'id',
        'project_id': 'project_id',
        'srclang': 'srclang',
        'trglang': 'trglang',
        'name': 'name',
        'import_in_progress': 'import_in_progress',
        'import_succeeded': 'import_succeeded',
        'import_error_message': 'import_error_message',
        'export_in_progress': 'export_in_progress',
        'export_succeeded': 'export_succeeded',
        'export_error_message': 'export_error_message',
        'is_pretranslating': 'is_pretranslating',
        'status': 'status',
        'translator_email': 'translator_email',
        'reviewer_email': 'reviewer_email',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, project_id=None, srclang=None, trglang=None, name=None, import_in_progress=None, import_succeeded=None, import_error_message=None, export_in_progress=None, export_succeeded=None, export_error_message=None, is_pretranslating=None, status=None, translator_email=None, reviewer_email=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """DocumentWithoutSegments - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._project_id = None
        self._srclang = None
        self._trglang = None
        self._name = None
        self._import_in_progress = None
        self._import_succeeded = None
        self._import_error_message = None
        self._export_in_progress = None
        self._export_succeeded = None
        self._export_error_message = None
        self._is_pretranslating = None
        self._status = None
        self._translator_email = None
        self._reviewer_email = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if project_id is not None:
            self.project_id = project_id
        if srclang is not None:
            self.srclang = srclang
        if trglang is not None:
            self.trglang = trglang
        if name is not None:
            self.name = name
        if import_in_progress is not None:
            self.import_in_progress = import_in_progress
        if import_succeeded is not None:
            self.import_succeeded = import_succeeded
        if import_error_message is not None:
            self.import_error_message = import_error_message
        if export_in_progress is not None:
            self.export_in_progress = export_in_progress
        if export_succeeded is not None:
            self.export_succeeded = export_succeeded
        if export_error_message is not None:
            self.export_error_message = export_error_message
        if is_pretranslating is not None:
            self.is_pretranslating = is_pretranslating
        if status is not None:
            self.status = status
        if translator_email is not None:
            self.translator_email = translator_email
        if reviewer_email is not None:
            self.reviewer_email = reviewer_email
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this DocumentWithoutSegments.  # noqa: E501

        A unique number identifying the Document.  # noqa: E501

        :return: The id of this DocumentWithoutSegments.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DocumentWithoutSegments.

        A unique number identifying the Document.  # noqa: E501

        :param id: The id of this DocumentWithoutSegments.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def project_id(self):
        """Gets the project_id of this DocumentWithoutSegments.  # noqa: E501

        A unique number identifying the Project.  # noqa: E501

        :return: The project_id of this DocumentWithoutSegments.  # noqa: E501
        :rtype: int
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this DocumentWithoutSegments.

        A unique number identifying the Project.  # noqa: E501

        :param project_id: The project_id of this DocumentWithoutSegments.  # noqa: E501
        :type: int
        """

        self._project_id = project_id

    @property
    def srclang(self):
        """Gets the srclang of this DocumentWithoutSegments.  # noqa: E501

        An ISO 639-1 language identifier.  # noqa: E501

        :return: The srclang of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._srclang

    @srclang.setter
    def srclang(self, srclang):
        """Sets the srclang of this DocumentWithoutSegments.

        An ISO 639-1 language identifier.  # noqa: E501

        :param srclang: The srclang of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._srclang = srclang

    @property
    def trglang(self):
        """Gets the trglang of this DocumentWithoutSegments.  # noqa: E501

        An ISO 639-1 language identifier.  # noqa: E501

        :return: The trglang of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._trglang

    @trglang.setter
    def trglang(self, trglang):
        """Sets the trglang of this DocumentWithoutSegments.

        An ISO 639-1 language identifier.  # noqa: E501

        :param trglang: The trglang of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._trglang = trglang

    @property
    def name(self):
        """Gets the name of this DocumentWithoutSegments.  # noqa: E501

        The document name.  # noqa: E501

        :return: The name of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentWithoutSegments.

        The document name.  # noqa: E501

        :param name: The name of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def import_in_progress(self):
        """Gets the import_in_progress of this DocumentWithoutSegments.  # noqa: E501

        True if the document is currently being imported  # noqa: E501

        :return: The import_in_progress of this DocumentWithoutSegments.  # noqa: E501
        :rtype: bool
        """
        return self._import_in_progress

    @import_in_progress.setter
    def import_in_progress(self, import_in_progress):
        """Sets the import_in_progress of this DocumentWithoutSegments.

        True if the document is currently being imported  # noqa: E501

        :param import_in_progress: The import_in_progress of this DocumentWithoutSegments.  # noqa: E501
        :type: bool
        """

        self._import_in_progress = import_in_progress

    @property
    def import_succeeded(self):
        """Gets the import_succeeded of this DocumentWithoutSegments.  # noqa: E501

        True if the import process succeeded.  # noqa: E501

        :return: The import_succeeded of this DocumentWithoutSegments.  # noqa: E501
        :rtype: bool
        """
        return self._import_succeeded

    @import_succeeded.setter
    def import_succeeded(self, import_succeeded):
        """Sets the import_succeeded of this DocumentWithoutSegments.

        True if the import process succeeded.  # noqa: E501

        :param import_succeeded: The import_succeeded of this DocumentWithoutSegments.  # noqa: E501
        :type: bool
        """

        self._import_succeeded = import_succeeded

    @property
    def import_error_message(self):
        """Gets the import_error_message of this DocumentWithoutSegments.  # noqa: E501

        Error message if `import_succeeded=false`  # noqa: E501

        :return: The import_error_message of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._import_error_message

    @import_error_message.setter
    def import_error_message(self, import_error_message):
        """Sets the import_error_message of this DocumentWithoutSegments.

        Error message if `import_succeeded=false`  # noqa: E501

        :param import_error_message: The import_error_message of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._import_error_message = import_error_message

    @property
    def export_in_progress(self):
        """Gets the export_in_progress of this DocumentWithoutSegments.  # noqa: E501

        True if the document is currently being exported for download  # noqa: E501

        :return: The export_in_progress of this DocumentWithoutSegments.  # noqa: E501
        :rtype: bool
        """
        return self._export_in_progress

    @export_in_progress.setter
    def export_in_progress(self, export_in_progress):
        """Sets the export_in_progress of this DocumentWithoutSegments.

        True if the document is currently being exported for download  # noqa: E501

        :param export_in_progress: The export_in_progress of this DocumentWithoutSegments.  # noqa: E501
        :type: bool
        """

        self._export_in_progress = export_in_progress

    @property
    def export_succeeded(self):
        """Gets the export_succeeded of this DocumentWithoutSegments.  # noqa: E501

        True if the export process succeeded.  # noqa: E501

        :return: The export_succeeded of this DocumentWithoutSegments.  # noqa: E501
        :rtype: bool
        """
        return self._export_succeeded

    @export_succeeded.setter
    def export_succeeded(self, export_succeeded):
        """Sets the export_succeeded of this DocumentWithoutSegments.

        True if the export process succeeded.  # noqa: E501

        :param export_succeeded: The export_succeeded of this DocumentWithoutSegments.  # noqa: E501
        :type: bool
        """

        self._export_succeeded = export_succeeded

    @property
    def export_error_message(self):
        """Gets the export_error_message of this DocumentWithoutSegments.  # noqa: E501

        Error message if `export_succeeded=false`  # noqa: E501

        :return: The export_error_message of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._export_error_message

    @export_error_message.setter
    def export_error_message(self, export_error_message):
        """Sets the export_error_message of this DocumentWithoutSegments.

        Error message if `export_succeeded=false`  # noqa: E501

        :param export_error_message: The export_error_message of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._export_error_message = export_error_message

    @property
    def is_pretranslating(self):
        """Gets the is_pretranslating of this DocumentWithoutSegments.  # noqa: E501

        True if the document is currently being pretranslated.  # noqa: E501

        :return: The is_pretranslating of this DocumentWithoutSegments.  # noqa: E501
        :rtype: bool
        """
        return self._is_pretranslating

    @is_pretranslating.setter
    def is_pretranslating(self, is_pretranslating):
        """Sets the is_pretranslating of this DocumentWithoutSegments.

        True if the document is currently being pretranslated.  # noqa: E501

        :param is_pretranslating: The is_pretranslating of this DocumentWithoutSegments.  # noqa: E501
        :type: bool
        """

        self._is_pretranslating = is_pretranslating

    @property
    def status(self):
        """Gets the status of this DocumentWithoutSegments.  # noqa: E501


        :return: The status of this DocumentWithoutSegments.  # noqa: E501
        :rtype: DocumentWithoutSegmentsStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DocumentWithoutSegments.


        :param status: The status of this DocumentWithoutSegments.  # noqa: E501
        :type: DocumentWithoutSegmentsStatus
        """

        self._status = status

    @property
    def translator_email(self):
        """Gets the translator_email of this DocumentWithoutSegments.  # noqa: E501

        The email of the assigned translator.  # noqa: E501

        :return: The translator_email of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._translator_email

    @translator_email.setter
    def translator_email(self, translator_email):
        """Sets the translator_email of this DocumentWithoutSegments.

        The email of the assigned translator.  # noqa: E501

        :param translator_email: The translator_email of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._translator_email = translator_email

    @property
    def reviewer_email(self):
        """Gets the reviewer_email of this DocumentWithoutSegments.  # noqa: E501

        The email of the assigned reviewer.  # noqa: E501

        :return: The reviewer_email of this DocumentWithoutSegments.  # noqa: E501
        :rtype: str
        """
        return self._reviewer_email

    @reviewer_email.setter
    def reviewer_email(self, reviewer_email):
        """Sets the reviewer_email of this DocumentWithoutSegments.

        The email of the assigned reviewer.  # noqa: E501

        :param reviewer_email: The reviewer_email of this DocumentWithoutSegments.  # noqa: E501
        :type: str
        """

        self._reviewer_email = reviewer_email

    @property
    def created_at(self):
        """Gets the created_at of this DocumentWithoutSegments.  # noqa: E501

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The created_at of this DocumentWithoutSegments.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this DocumentWithoutSegments.

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :param created_at: The created_at of this DocumentWithoutSegments.  # noqa: E501
        :type: int
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this DocumentWithoutSegments.  # noqa: E501

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The updated_at of this DocumentWithoutSegments.  # noqa: E501
        :rtype: int
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this DocumentWithoutSegments.

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :param updated_at: The updated_at of this DocumentWithoutSegments.  # noqa: E501
        :type: int
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentWithoutSegments):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DocumentWithoutSegments):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class SourceFile(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'file_hash': 'str',
        'detected_lang': 'str',
        'detected_lang_confidence': 'float',
        'category': 'str',
        'labels': 'list[str]',
        'created_at': 'int',
        'updated_at': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'file_hash': 'file_hash',
        'detected_lang': 'detected_lang',
        'detected_lang_confidence': 'detected_lang_confidence',
        'category': 'category',
        'labels': 'labels',
        'created_at': 'created_at',
        'updated_at': 'updated_at'
    }

    def __init__(self, id=None, name=None, file_hash=None, detected_lang=None, detected_lang_confidence=None, category=None, labels=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """SourceFile - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._file_hash = None
        self._detected_lang = None
        self._detected_lang_confidence = None
        self._category = None
        self._labels = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if file_hash is not None:
            self.file_hash = file_hash
        if detected_lang is not None:
            self.detected_lang = detected_lang
        if detected_lang_confidence is not None:
            self.detected_lang_confidence = detected_lang_confidence
        if category is not None:
            self.category = category
        if labels is not None:
            self.labels = labels
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this SourceFile.  # noqa: E501

        A unique number identifying the SourceFile.  # noqa: E501

        :return: The id of this SourceFile.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SourceFile.

        A unique number identifying the SourceFile.  # noqa: E501

        :param id: The id of this SourceFile.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this SourceFile.  # noqa: E501

        The file name.  # noqa: E501

        :return: The name of this SourceFile.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SourceFile.

        The file name.  # noqa: E501

        :param name: The name of this SourceFile.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def file_hash(self):
        """Gets the file_hash of this SourceFile.  # noqa: E501

        A unique hash value associated with the file. An MD5 hash of the file content will be used by default.  # noqa: E501

        :return: The file_hash of this SourceFile.  # noqa: E501
        :rtype: str
        """
        return self._file_hash

    @file_hash.setter
    def file_hash(self, file_hash):
        """Sets the file_hash of this SourceFile.

        A unique hash value associated with the file. An MD5 hash of the file content will be used by default.  # noqa: E501

        :param file_hash: The file_hash of this SourceFile.  # noqa: E501
        :type: str
        """

        self._file_hash = file_hash

    @property
    def detected_lang(self):
        """Gets the detected_lang of this SourceFile.  # noqa: E501

        Language associated with the file.  # noqa: E501

        :return: The detected_lang of this SourceFile.  # noqa: E501
        :rtype: str
        """
        return self._detected_lang

    @detected_lang.setter
    def detected_lang(self, detected_lang):
        """Sets the detected_lang of this SourceFile.

        Language associated with the file.  # noqa: E501

        :param detected_lang: The detected_lang of this SourceFile.  # noqa: E501
        :type: str
        """

        self._detected_lang = detected_lang

    @property
    def detected_lang_confidence(self):
        """Gets the detected_lang_confidence of this SourceFile.  # noqa: E501

        Confidence score for the language associated with the file.  # noqa: E501

        :return: The detected_lang_confidence of this SourceFile.  # noqa: E501
        :rtype: float
        """
        return self._detected_lang_confidence

    @detected_lang_confidence.setter
    def detected_lang_confidence(self, detected_lang_confidence):
        """Sets the detected_lang_confidence of this SourceFile.

        Confidence score for the language associated with the file.  # noqa: E501

        :param detected_lang_confidence: The detected_lang_confidence of this SourceFile.  # noqa: E501
        :type: float
        """

        self._detected_lang_confidence = detected_lang_confidence

    @property
    def category(self):
        """Gets the category of this SourceFile.  # noqa: E501

        The category of the file. The options are `REFERENCE`, or `API`. The default is API. Files with the `REFERENCE` category will be displayed as reference material.  # noqa: E501

        :return: The category of this SourceFile.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this SourceFile.

        The category of the file. The options are `REFERENCE`, or `API`. The default is API. Files with the `REFERENCE` category will be displayed as reference material.  # noqa: E501

        :param category: The category of this SourceFile.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def labels(self):
        """Gets the labels of this SourceFile.  # noqa: E501

        The list of labels associated with the file.  # noqa: E501

        :return: The labels of this SourceFile.  # noqa: E501
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this SourceFile.

        The list of labels associated with the file.  # noqa: E501

        :param labels: The labels of this SourceFile.  # noqa: E501
        :type: list[str]
        """

        self._labels = labels

    @property
    def created_at(self):
        """Gets the created_at of this SourceFile.  # noqa: E501

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The created_at of this SourceFile.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this SourceFile.

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :param created_at: The created_at of this SourceFile.  # noqa: E501
        :type: int
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this SourceFile.  # noqa: E501

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The updated_at of this SourceFile.  # noqa: E501
        :rtype: int
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this SourceFile.

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :param updated_at: The updated_at of this SourceFile.  # noqa: E501
        :type: int
        """

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SourceFile):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SourceFile):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class LanguagePair(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'src_lang': 'str',
        'src_locale': 'str',
        'trg_lang': 'str',
        'trg_locale': 'str',
        'due_date': 'str',
        'memory_id': 'int',
        'pretranslate': 'bool',
        'auto_accept': 'bool',
        'case_sensitive': 'bool',
        'take_match_attribution': 'bool',
        'config_id': 'int'
    }

    attribute_map = {
        'src_lang': 'srcLang',
        'src_locale': 'srcLocale',
        'trg_lang': 'trgLang',
        'trg_locale': 'trgLocale',
        'due_date': 'dueDate',
        'memory_id': 'memoryId',
        'pretranslate': 'pretranslate',
        'auto_accept': 'autoAccept',
        'case_sensitive': 'caseSensitive',
        'take_match_attribution': 'takeMatchAttribution',
        'config_id': 'configId'
    }

    def __init__(self, src_lang=None, src_locale=None, trg_lang=None, trg_locale=None, due_date=None, memory_id=None, pretranslate=None, auto_accept=None, case_sensitive=None, take_match_attribution=None, config_id=None, local_vars_configuration=None):  # noqa: E501
        """LanguagePair - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._src_lang = None
        self._src_locale = None
        self._trg_lang = None
        self._trg_locale = None
        self._due_date = None
        self._memory_id = None
        self._pretranslate = None
        self._auto_accept = None
        self._case_sensitive = None
        self._take_match_attribution = None
        self._config_id = None
        self.discriminator = None

        if src_lang is not None:
            self.src_lang = src_lang
        if src_locale is not None:
            self.src_locale = src_locale
        self.trg_lang = trg_lang
        if trg_locale is not None:
            self.trg_locale = trg_locale
        if due_date is not None:
            self.due_date = due_date
        self.memory_id = memory_id
        if pretranslate is not None:
            self.pretranslate = pretranslate
        if auto_accept is not None:
            self.auto_accept = auto_accept
        if case_sensitive is not None:
            self.case_sensitive = case_sensitive
        if take_match_attribution is not None:
            self.take_match_attribution = take_match_attribution
        if config_id is not None:
            self.config_id = config_id

    @property
    def src_lang(self):
        """Gets the src_lang of this LanguagePair.  # noqa: E501

        Source langauge, an ISO 639-1 language identifier.  # noqa: E501

        :return: The src_lang of this LanguagePair.  # noqa: E501
        :rtype: str
        """
        return self._src_lang

    @src_lang.setter
    def src_lang(self, src_lang):
        """Sets the src_lang of this LanguagePair.

        Source langauge, an ISO 639-1 language identifier.  # noqa: E501

        :param src_lang: The src_lang of this LanguagePair.  # noqa: E501
        :type: str
        """

        self._src_lang = src_lang

    @property
    def src_locale(self):
        """Gets the src_locale of this LanguagePair.  # noqa: E501

        A locale identifier, supported for source langauge.  # noqa: E501

        :return: The src_locale of this LanguagePair.  # noqa: E501
        :rtype: str
        """
        return self._src_locale

    @src_locale.setter
    def src_locale(self, src_locale):
        """Sets the src_locale of this LanguagePair.

        A locale identifier, supported for source langauge.  # noqa: E501

        :param src_locale: The src_locale of this LanguagePair.  # noqa: E501
        :type: str
        """

        self._src_locale = src_locale

    @property
    def trg_lang(self):
        """Gets the trg_lang of this LanguagePair.  # noqa: E501

        Target langauge, an ISO 639-1 language identifier.  # noqa: E501

        :return: The trg_lang of this LanguagePair.  # noqa: E501
        :rtype: str
        """
        return self._trg_lang

    @trg_lang.setter
    def trg_lang(self, trg_lang):
        """Sets the trg_lang of this LanguagePair.

        Target langauge, an ISO 639-1 language identifier.  # noqa: E501

        :param trg_lang: The trg_lang of this LanguagePair.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and trg_lang is None:  # noqa: E501
            raise ValueError("Invalid value for `trg_lang`, must not be `None`")  # noqa: E501

        self._trg_lang = trg_lang

    @property
    def trg_locale(self):
        """Gets the trg_locale of this LanguagePair.  # noqa: E501

        A locale identifier, supported for target language.  # noqa: E501

        :return: The trg_locale of this LanguagePair.  # noqa: E501
        :rtype: str
        """
        return self._trg_locale

    @trg_locale.setter
    def trg_locale(self, trg_locale):
        """Sets the trg_locale of this LanguagePair.

        A locale identifier, supported for target language.  # noqa: E501

        :param trg_locale: The trg_locale of this LanguagePair.  # noqa: E501
        :type: str
        """

        self._trg_locale = trg_locale

    @property
    def due_date(self):
        """Gets the due_date of this LanguagePair.  # noqa: E501

        An ISO date.  # noqa: E501

        :return: The due_date of this LanguagePair.  # noqa: E501
        :rtype: str
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this LanguagePair.

        An ISO date.  # noqa: E501

        :param due_date: The due_date of this LanguagePair.  # noqa: E501
        :type: str
        """

        self._due_date = due_date

    @property
    def memory_id(self):
        """Gets the memory_id of this LanguagePair.  # noqa: E501

        A unique number identifying the associated Memory.  # noqa: E501

        :return: The memory_id of this LanguagePair.  # noqa: E501
        :rtype: int
        """
        return self._memory_id

    @memory_id.setter
    def memory_id(self, memory_id):
        """Sets the memory_id of this LanguagePair.

        A unique number identifying the associated Memory.  # noqa: E501

        :param memory_id: The memory_id of this LanguagePair.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and memory_id is None:  # noqa: E501
            raise ValueError("Invalid value for `memory_id`, must not be `None`")  # noqa: E501

        self._memory_id = memory_id

    @property
    def pretranslate(self):
        """Gets the pretranslate of this LanguagePair.  # noqa: E501

        Attribute translation authorship of exact matches to the creator of the document being pretranslated.  # noqa: E501

        :return: The pretranslate of this LanguagePair.  # noqa: E501
        :rtype: bool
        """
        return self._pretranslate

    @pretranslate.setter
    def pretranslate(self, pretranslate):
        """Sets the pretranslate of this LanguagePair.

        Attribute translation authorship of exact matches to the creator of the document being pretranslated.  # noqa: E501

        :param pretranslate: The pretranslate of this LanguagePair.  # noqa: E501
        :type: bool
        """

        self._pretranslate = pretranslate

    @property
    def auto_accept(self):
        """Gets the auto_accept of this LanguagePair.  # noqa: E501

        Accept and lock exact matches.  # noqa: E501

        :return: The auto_accept of this LanguagePair.  # noqa: E501
        :rtype: bool
        """
        return self._auto_accept

    @auto_accept.setter
    def auto_accept(self, auto_accept):
        """Sets the auto_accept of this LanguagePair.

        Accept and lock exact matches.  # noqa: E501

        :param auto_accept: The auto_accept of this LanguagePair.  # noqa: E501
        :type: bool
        """

        self._auto_accept = auto_accept

    @property
    def case_sensitive(self):
        """Gets the case_sensitive of this LanguagePair.  # noqa: E501

        Use case sensitive translation memory matching.  # noqa: E501

        :return: The case_sensitive of this LanguagePair.  # noqa: E501
        :rtype: bool
        """
        return self._case_sensitive

    @case_sensitive.setter
    def case_sensitive(self, case_sensitive):
        """Sets the case_sensitive of this LanguagePair.

        Use case sensitive translation memory matching.  # noqa: E501

        :param case_sensitive: The case_sensitive of this LanguagePair.  # noqa: E501
        :type: bool
        """

        self._case_sensitive = case_sensitive

    @property
    def take_match_attribution(self):
        """Gets the take_match_attribution of this LanguagePair.  # noqa: E501

        Use MT for unmatched segments.  # noqa: E501

        :return: The take_match_attribution of this LanguagePair.  # noqa: E501
        :rtype: bool
        """
        return self._take_match_attribution

    @take_match_attribution.setter
    def take_match_attribution(self, take_match_attribution):
        """Sets the take_match_attribution of this LanguagePair.

        Use MT for unmatched segments.  # noqa: E501

        :param take_match_attribution: The take_match_attribution of this LanguagePair.  # noqa: E501
        :type: bool
        """

        self._take_match_attribution = take_match_attribution

    @property
    def config_id(self):
        """Gets the config_id of this LanguagePair.  # noqa: E501

        Configuration id  # noqa: E501

        :return: The config_id of this LanguagePair.  # noqa: E501
        :rtype: int
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """Sets the config_id of this LanguagePair.

        Configuration id  # noqa: E501

        :param config_id: The config_id of this LanguagePair.  # noqa: E501
        :type: int
        """

        self._config_id = config_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LanguagePair):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LanguagePair):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class ResourceStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'email': 'str',
        'name': 'str',
        'num_words_confirmed': 'int',
        'num_words_new': 'int',
        'num_words_fuzzy': 'int',
        'num_words_exact': 'int',
        'num_words_reviewed': 'int',
        'time_elapsed': 'int',
        'time_elapsed_translation': 'int',
        'time_elapsed_research': 'int',
        'time_elapsed_review': 'int',
        'num_segments_confirmed': 'int',
        'num_segments_reviewed': 'int'
    }

    attribute_map = {
        'email': 'email',
        'name': 'name',
        'num_words_confirmed': 'num_words_confirmed',
        'num_words_new': 'num_words_new',
        'num_words_fuzzy': 'num_words_fuzzy',
        'num_words_exact': 'num_words_exact',
        'num_words_reviewed': 'num_words_reviewed',
        'time_elapsed': 'time_elapsed',
        'time_elapsed_translation': 'time_elapsed_translation',
        'time_elapsed_research': 'time_elapsed_research',
        'time_elapsed_review': 'time_elapsed_review',
        'num_segments_confirmed': 'num_segments_confirmed',
        'num_segments_reviewed': 'num_segments_reviewed'
    }

    def __init__(self, email=None, name=None, num_words_confirmed=None, num_words_new=None, num_words_fuzzy=None, num_words_exact=None, num_words_reviewed=None, time_elapsed=None, time_elapsed_translation=None, time_elapsed_research=None, time_elapsed_review=None, num_segments_confirmed=None, num_segments_reviewed=None, local_vars_configuration=None):  # noqa: E501
        """ResourceStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._email = None
        self._name = None
        self._num_words_confirmed = None
        self._num_words_new = None
        self._num_words_fuzzy = None
        self._num_words_exact = None
        self._num_words_reviewed = None
        self._time_elapsed = None
        self._time_elapsed_translation = None
        self._time_elapsed_research = None
        self._time_elapsed_review = None
        self._num_segments_confirmed = None
        self._num_segments_reviewed = None
        self.discriminator = None

        if email is not None:
            self.email = email
        if name is not None:
            self.name = name
        if num_words_confirmed is not None:
            self.num_words_confirmed = num_words_confirmed
        if num_words_new is not None:
            self.num_words_new = num_words_new
        if num_words_fuzzy is not None:
            self.num_words_fuzzy = num_words_fuzzy
        if num_words_exact is not None:
            self.num_words_exact = num_words_exact
        if num_words_reviewed is not None:
            self.num_words_reviewed = num_words_reviewed
        if time_elapsed is not None:
            self.time_elapsed = time_elapsed
        if time_elapsed_translation is not None:
            self.time_elapsed_translation = time_elapsed_translation
        if time_elapsed_research is not None:
            self.time_elapsed_research = time_elapsed_research
        if time_elapsed_review is not None:
            self.time_elapsed_review = time_elapsed_review
        if num_segments_confirmed is not None:
            self.num_segments_confirmed = num_segments_confirmed
        if num_segments_reviewed is not None:
            self.num_segments_reviewed = num_segments_reviewed

    @property
    def email(self):
        """Gets the email of this ResourceStatus.  # noqa: E501

        An email address.  # noqa: E501

        :return: The email of this ResourceStatus.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this ResourceStatus.

        An email address.  # noqa: E501

        :param email: The email of this ResourceStatus.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def name(self):
        """Gets the name of this ResourceStatus.  # noqa: E501

        The full name.  # noqa: E501

        :return: The name of this ResourceStatus.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ResourceStatus.

        The full name.  # noqa: E501

        :param name: The name of this ResourceStatus.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def num_words_confirmed(self):
        """Gets the num_words_confirmed of this ResourceStatus.  # noqa: E501

        The number of source words confirmed.  # noqa: E501

        :return: The num_words_confirmed of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_words_confirmed

    @num_words_confirmed.setter
    def num_words_confirmed(self, num_words_confirmed):
        """Sets the num_words_confirmed of this ResourceStatus.

        The number of source words confirmed.  # noqa: E501

        :param num_words_confirmed: The num_words_confirmed of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_words_confirmed = num_words_confirmed

    @property
    def num_words_new(self):
        """Gets the num_words_new of this ResourceStatus.  # noqa: E501

        The number of new source words confirmed.  # noqa: E501

        :return: The num_words_new of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_words_new

    @num_words_new.setter
    def num_words_new(self, num_words_new):
        """Sets the num_words_new of this ResourceStatus.

        The number of new source words confirmed.  # noqa: E501

        :param num_words_new: The num_words_new of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_words_new = num_words_new

    @property
    def num_words_fuzzy(self):
        """Gets the num_words_fuzzy of this ResourceStatus.  # noqa: E501

        The number of fuzzy match source words confirmed.  # noqa: E501

        :return: The num_words_fuzzy of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_words_fuzzy

    @num_words_fuzzy.setter
    def num_words_fuzzy(self, num_words_fuzzy):
        """Sets the num_words_fuzzy of this ResourceStatus.

        The number of fuzzy match source words confirmed.  # noqa: E501

        :param num_words_fuzzy: The num_words_fuzzy of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_words_fuzzy = num_words_fuzzy

    @property
    def num_words_exact(self):
        """Gets the num_words_exact of this ResourceStatus.  # noqa: E501

        The number of exact match source words confirmed.  # noqa: E501

        :return: The num_words_exact of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_words_exact

    @num_words_exact.setter
    def num_words_exact(self, num_words_exact):
        """Sets the num_words_exact of this ResourceStatus.

        The number of exact match source words confirmed.  # noqa: E501

        :param num_words_exact: The num_words_exact of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_words_exact = num_words_exact

    @property
    def num_words_reviewed(self):
        """Gets the num_words_reviewed of this ResourceStatus.  # noqa: E501

        The number of source words reviewed.  # noqa: E501

        :return: The num_words_reviewed of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_words_reviewed

    @num_words_reviewed.setter
    def num_words_reviewed(self, num_words_reviewed):
        """Sets the num_words_reviewed of this ResourceStatus.

        The number of source words reviewed.  # noqa: E501

        :param num_words_reviewed: The num_words_reviewed of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_words_reviewed = num_words_reviewed

    @property
    def time_elapsed(self):
        """Gets the time_elapsed of this ResourceStatus.  # noqa: E501

        The total time spent on translation and research. Measured in milliseconds.  # noqa: E501

        :return: The time_elapsed of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._time_elapsed

    @time_elapsed.setter
    def time_elapsed(self, time_elapsed):
        """Sets the time_elapsed of this ResourceStatus.

        The total time spent on translation and research. Measured in milliseconds.  # noqa: E501

        :param time_elapsed: The time_elapsed of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._time_elapsed = time_elapsed

    @property
    def time_elapsed_translation(self):
        """Gets the time_elapsed_translation of this ResourceStatus.  # noqa: E501

        The total time spent translating. Measured in milliseconds.  # noqa: E501

        :return: The time_elapsed_translation of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._time_elapsed_translation

    @time_elapsed_translation.setter
    def time_elapsed_translation(self, time_elapsed_translation):
        """Sets the time_elapsed_translation of this ResourceStatus.

        The total time spent translating. Measured in milliseconds.  # noqa: E501

        :param time_elapsed_translation: The time_elapsed_translation of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._time_elapsed_translation = time_elapsed_translation

    @property
    def time_elapsed_research(self):
        """Gets the time_elapsed_research of this ResourceStatus.  # noqa: E501

        The total time spent on research. Measured in milliseconds.  # noqa: E501

        :return: The time_elapsed_research of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._time_elapsed_research

    @time_elapsed_research.setter
    def time_elapsed_research(self, time_elapsed_research):
        """Sets the time_elapsed_research of this ResourceStatus.

        The total time spent on research. Measured in milliseconds.  # noqa: E501

        :param time_elapsed_research: The time_elapsed_research of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._time_elapsed_research = time_elapsed_research

    @property
    def time_elapsed_review(self):
        """Gets the time_elapsed_review of this ResourceStatus.  # noqa: E501

        The total time spent reviewing. Measured in milliseconds.  # noqa: E501

        :return: The time_elapsed_review of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._time_elapsed_review

    @time_elapsed_review.setter
    def time_elapsed_review(self, time_elapsed_review):
        """Sets the time_elapsed_review of this ResourceStatus.

        The total time spent reviewing. Measured in milliseconds.  # noqa: E501

        :param time_elapsed_review: The time_elapsed_review of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._time_elapsed_review = time_elapsed_review

    @property
    def num_segments_confirmed(self):
        """Gets the num_segments_confirmed of this ResourceStatus.  # noqa: E501

        The number of source segments confirmed.  # noqa: E501

        :return: The num_segments_confirmed of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_segments_confirmed

    @num_segments_confirmed.setter
    def num_segments_confirmed(self, num_segments_confirmed):
        """Sets the num_segments_confirmed of this ResourceStatus.

        The number of source segments confirmed.  # noqa: E501

        :param num_segments_confirmed: The num_segments_confirmed of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_segments_confirmed = num_segments_confirmed

    @property
    def num_segments_reviewed(self):
        """Gets the num_segments_reviewed of this ResourceStatus.  # noqa: E501

        The number of source segments reviewed.  # noqa: E501

        :return: The num_segments_reviewed of this ResourceStatus.  # noqa: E501
        :rtype: int
        """
        return self._num_segments_reviewed

    @num_segments_reviewed.setter
    def num_segments_reviewed(self, num_segments_reviewed):
        """Sets the num_segments_reviewed of this ResourceStatus.

        The number of source segments reviewed.  # noqa: E501

        :param num_segments_reviewed: The num_segments_reviewed of this ResourceStatus.  # noqa: E501
        :type: int
        """

        self._num_segments_reviewed = num_segments_reviewed

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResourceStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class ProjectUpdateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'name': 'str',
        'state': 'str',
        'due_date': 'int',
        'archived': 'bool',
        'metadata': 'object',
        'sample_review_percentage': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'state': 'state',
        'due_date': 'due_date',
        'archived': 'archived',
        'metadata': 'metadata',
        'sample_review_percentage': 'sample_review_percentage'
    }

    def __init__(self, id=None, name=None, state=None, due_date=None, archived=None, metadata=None, sample_review_percentage=None, local_vars_configuration=None):  # noqa: E501
        """ProjectUpdateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._state = None
        self._due_date = None
        self._archived = None
        self._metadata = None
        self._sample_review_percentage = None
        self.discriminator = None

        self.id = id
        if name is not None:
            self.name = name
        if state is not None:
            self.state = state
        if due_date is not None:
            self.due_date = due_date
        if archived is not None:
            self.archived = archived
        if metadata is not None:
            self.metadata = metadata
        if sample_review_percentage is not None:
            self.sample_review_percentage = sample_review_percentage

    @property
    def id(self):
        """Gets the id of this ProjectUpdateResponse.  # noqa: E501

        A unique Project identifier.  # noqa: E501

        :return: The id of this ProjectUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProjectUpdateResponse.

        A unique Project identifier.  # noqa: E501

        :param id: The id of this ProjectUpdateResponse.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ProjectUpdateResponse.  # noqa: E501

        The Project name.  # noqa: E501

        :return: The name of this ProjectUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ProjectUpdateResponse.

        The Project name.  # noqa: E501

        :param name: The name of this ProjectUpdateResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def state(self):
        """Gets the state of this ProjectUpdateResponse.  # noqa: E501

        The project's state. The possible states are 'backlog', 'inProgress', 'inReview', 'inQA', and 'done'  # noqa: E501

        :return: The state of this ProjectUpdateResponse.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ProjectUpdateResponse.

        The project's state. The possible states are 'backlog', 'inProgress', 'inReview', 'inQA', and 'done'  # noqa: E501

        :param state: The state of this ProjectUpdateResponse.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def due_date(self):
        """Gets the due_date of this ProjectUpdateResponse.  # noqa: E501

        The due date. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The due_date of this ProjectUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this ProjectUpdateResponse.

        The due date. Measured in seconds since the Unix epoch.  # noqa: E501

        :param due_date: The due_date of this ProjectUpdateResponse.  # noqa: E501
        :type: int
        """

        self._due_date = due_date

    @property
    def archived(self):
        """Gets the archived of this ProjectUpdateResponse.  # noqa: E501

        True if the project is archived. Otherwise, false.  # noqa: E501

        :return: The archived of this ProjectUpdateResponse.  # noqa: E501
        :rtype: bool
        """
        return self._archived

    @archived.setter
    def archived(self, archived):
        """Sets the archived of this ProjectUpdateResponse.

        True if the project is archived. Otherwise, false.  # noqa: E501

        :param archived: The archived of this ProjectUpdateResponse.  # noqa: E501
        :type: bool
        """

        self._archived = archived

    @property
    def metadata(self):
        """Gets the metadata of this ProjectUpdateResponse.  # noqa: E501

        Metadata associated with a project. This field must be valid JSON.  # noqa: E501

        :return: The metadata of this ProjectUpdateResponse.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ProjectUpdateResponse.

        Metadata associated with a project. This field must be valid JSON.  # noqa: E501

        :param metadata: The metadata of this ProjectUpdateResponse.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def sample_review_percentage(self):
        """Gets the sample_review_percentage of this ProjectUpdateResponse.  # noqa: E501

        The Project's sample review percentage. Must be an integer between 10 and 100, a multiple of 10 and greater than minimum value (displayed in error message).  # noqa: E501

        :return: The sample_review_percentage of this ProjectUpdateResponse.  # noqa: E501
        :rtype: int
        """
        return self._sample_review_percentage

    @sample_review_percentage.setter
    def sample_review_percentage(self, sample_review_percentage):
        """Sets the sample_review_percentage of this ProjectUpdateResponse.

        The Project's sample review percentage. Must be an integer between 10 and 100, a multiple of 10 and greater than minimum value (displayed in error message).  # noqa: E501

        :param sample_review_percentage: The sample_review_percentage of this ProjectUpdateResponse.  # noqa: E501
        :type: int
        """

        self._sample_review_percentage = sample_review_percentage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProjectUpdateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProjectUpdateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from lilt.models.add_file_label_request import AddFileLabelRequest
from lilt.models.annotation import Annotation
from lilt.models.api_root import ApiRoot
from lilt.models.comment import Comment
from lilt.models.comment_body import CommentBody
from lilt.models.comment_delete_response import CommentDeleteResponse
from lilt.models.connector import Connector
from lilt.models.connector_arguments import ConnectorArguments
from lilt.models.connector_delete_response import ConnectorDeleteResponse
from lilt.models.connector_job import ConnectorJob
from lilt.models.converter_config_update_response import ConverterConfigUpdateResponse
from lilt.models.create_converter_config_parameters import CreateConverterConfigParameters
from lilt.models.document_assignment_parameters import DocumentAssignmentParameters
from lilt.models.document_assignment_response import DocumentAssignmentResponse
from lilt.models.document_comments import DocumentComments
from lilt.models.document_delete_response import DocumentDeleteResponse
from lilt.models.document_done_update_parameters import DocumentDoneUpdateParameters
from lilt.models.document_done_update_parameters1 import DocumentDoneUpdateParameters1
from lilt.models.document_done_update_parameters2 import DocumentDoneUpdateParameters2
from lilt.models.document_parameters import DocumentParameters
from lilt.models.document_pretranslate_parameters import DocumentPretranslateParameters
from lilt.models.document_pretranslate_response import DocumentPretranslateResponse
from lilt.models.document_pretranslating import DocumentPretranslating
from lilt.models.document_pretranslating_status import DocumentPretranslatingStatus
from lilt.models.document_quote import DocumentQuote
from lilt.models.document_update_parameters import DocumentUpdateParameters
from lilt.models.document_with_segments import DocumentWithSegments
from lilt.models.document_without_segments import DocumentWithoutSegments
from lilt.models.document_without_segments_status import DocumentWithoutSegmentsStatus
from lilt.models.edit_filter_mapping_parameters import EditFilterMappingParameters
from lilt.models.error import Error
from lilt.models.file_delete_response import FileDeleteResponse
from lilt.models.job import Job
from lilt.models.job_create_parameters import JobCreateParameters
from lilt.models.job_delete_response import JobDeleteResponse
from lilt.models.job_leverage_stats import JobLeverageStats
from lilt.models.job_leverage_stats_projects import JobLeverageStatsProjects
from lilt.models.job_project import JobProject
from lilt.models.job_stats import JobStats
from lilt.models.job_update_parameters import JobUpdateParameters
from lilt.models.language_pair import LanguagePair
from lilt.models.languages_response import LanguagesResponse
from lilt.models.lexicon_entry import LexiconEntry
from lilt.models.lexicon_entry_examples import LexiconEntryExamples
from lilt.models.lexicon_entry_source_span import LexiconEntrySourceSpan
from lilt.models.lexicon_entry_target_span import LexiconEntryTargetSpan
from lilt.models.lexicon_entry_translations import LexiconEntryTranslations
from lilt.models.lexicon_update_parameters import LexiconUpdateParameters
from lilt.models.lexicon_update_response import LexiconUpdateResponse
from lilt.models.match_band import MatchBand
from lilt.models.memory import Memory
from lilt.models.memory_create_parameters import MemoryCreateParameters
from lilt.models.memory_delete_response import MemoryDeleteResponse
from lilt.models.memory_import_response import MemoryImportResponse
from lilt.models.memory_insert_response import MemoryInsertResponse
from lilt.models.memory_update_parameters import MemoryUpdateParameters
from lilt.models.memory_update_response import MemoryUpdateResponse
from lilt.models.project import Project
from lilt.models.project_create_parameters import ProjectCreateParameters
from lilt.models.project_delete_response import ProjectDeleteResponse
from lilt.models.project_quote import ProjectQuote
from lilt.models.project_status import ProjectStatus
from lilt.models.project_update_response import ProjectUpdateResponse
from lilt.models.qa_rule_matches import QARuleMatches
from lilt.models.qa_rule_matches_context import QARuleMatchesContext
from lilt.models.qa_rule_matches_custom_rules import QARuleMatchesCustomRules
from lilt.models.qa_rule_matches_matches import QARuleMatchesMatches
from lilt.models.qa_rule_matches_replacements import QARuleMatchesReplacements
from lilt.models.qa_rule_matches_rule import QARuleMatchesRule
from lilt.models.qa_rule_matches_rule_category import QARuleMatchesRuleCategory
from lilt.models.qa_rule_matches_rule_urls import QARuleMatchesRuleUrls
from lilt.models.resource_status import ResourceStatus
from lilt.models.segment import Segment
from lilt.models.segment_create_parameters import SegmentCreateParameters
from lilt.models.segment_delete_response import SegmentDeleteResponse
from lilt.models.segment_done_response import SegmentDoneResponse
from lilt.models.segment_update_parameters import SegmentUpdateParameters
from lilt.models.segment_with_comments import SegmentWithComments
from lilt.models.setting import Setting
from lilt.models.setting_upsert_body import SettingUpsertBody
from lilt.models.setting_upsert_response import SettingUpsertResponse
from lilt.models.source_file import SourceFile
from lilt.models.tagged_segment import TaggedSegment
from lilt.models.translate_register_response import TranslateRegisterResponse
from lilt.models.translation import Translation
from lilt.models.translation_info import TranslationInfo
from lilt.models.translation_list import TranslationList
from lilt.models.translation_memory_entry import TranslationMemoryEntry



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

# from unittest.mock import Mock
from unittest.mock import Mock, patch
import json

import lilt
from lilt.api.documents_api import DocumentsApi  # noqa: E501
from lilt.rest import ApiException


class TestDocumentsApi(unittest.TestCase):
    """DocumentsApi unit test stubs"""

    def setUp(self):
        self.api = lilt.api.documents_api.DocumentsApi()  # noqa: E501

    def tearDown(self):
        pass

    @patch.object(lilt.ApiClient, "request")
    def test_create_document(self, mock_request):
        """Test case for create_document

        Create a Document  # noqa: E501
        """
        mock_response = Mock()
        mock_response.data = json.dumps({"id": 46530})
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        body = {"name": "Introduction.xliff", "project_id": 23618}
        r = doc_api.create_document(body=body)
        assert r.id == 46530

    @patch.object(lilt.ApiClient, "request")
    def test_assign_document(self, mock_request):
        """Test case for assign_document

        Assign a Document  # noqa: E501
        """
        mock_response = Mock()
        mock_response.data = json.dumps({"id": 46530})
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        body = {
            "id": 46530,
            "email": "user@email.com",
            "is_translator": True,
            "is_reviewer": False,
            "due_date": "2019-10-16T22:12:34.000Z",
        }

        assignment_response = doc_api.assign_document(body)
        assert assignment_response.id == 46530

    @patch.object(lilt.ApiClient, "request")
    def test_delete_document(self, mock_request):
        """Test case for delete_document

        Delete a Document  # noqa: E501
        """
        mock_response = Mock()
        mock_response.data = json.dumps({"id": 46530, "deleted": True})
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        r = doc_api.delete_document(46530)
        assert r.id == 46530
        assert r.deleted == True

    @patch.object(lilt.ApiClient, "request")
    def test_download_file(self, mock_request):
        """Test case for download_file

        Download a File  # noqa: E501
        """
        mock_client = Mock()
        vR = "file"
        mock_client.call_api.return_value = vR
        doc_api = DocumentsApi(mock_client)

        r = doc_api.download_file(46530)
        assert r == vR
        assert mock_client.call_api.call_count == 1

    @patch.object(lilt.ApiClient, "request")
    def test_get_document(self, mock_request):
        """Test case for get_document

        Retrieve a Document  # noqa: E501
        """
        mock_response = Mock()
        data = None
        with open("test_resources/get_documents.json") as f:
            data = json.load(f)
        mock_response.data = json.dumps(data)
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        r = doc_api.get_document(46530)
        assert r.id == 46530

    @patch.object(lilt.ApiClient, "request")
    def test_pretranslate_document(self,mock_request):
        """Test case for pretranslate_document

        Pretranslate a Document  # noqa: E501
        """
        mock_response = Mock()
        data = None
        with open("test_resources/post_translate.json") as f:
            data = json.load(f)
        mock_response.data = json.dumps(data)
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        body = {"id": [123, 234]}
        r = doc_api.pretranslate_documents(body=body)
        assert r.is_pretranslating == True

    @patch.object(lilt.ApiClient, "request")
    def test_update_document(self, mock_request):
        """Test case for update_document

        Update a Document  # noqa: E501
        """
        mock_response = Mock()
        data = None
        with open("test_resources/put_documents.json") as f:
            data = json.load(f)
        mock_response.data = json.dumps(data)
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        body = {"id": 46530, "name": "Introduction to our App"}
        r = doc_api.update_document(body)
        assert r.id == 46530

    @patch.object(lilt.ApiClient, "request")
    def test_upload_document_file(self, mock_request):
        """Test case for upload_document_file

        Upload a File  # noqa: E501
        """
        mock_response = Mock()
        data = None
        with open("test_resources/post_documents.json") as f:
            data = json.load(f)
        mock_response.data = json.dumps(data)
        mock_request.return_value = mock_response
        api_client = lilt.ApiClient()
        doc_api = DocumentsApi(api_client)

        body = "file"
        r = doc_api.upload_document_file("test", 4234, body)
        assert r.id == 46530


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class LexiconEntryExamples(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'source': 'str',
        'source_delimiters': 'list[str]',
        'target': 'str',
        'target_delimiters': 'list[str]',
        'source_span': 'LexiconEntrySourceSpan',
        'target_span': 'LexiconEntryTargetSpan',
        'similarity': 'float',
        'memory_id': 'float'
    }

    attribute_map = {
        'source': 'source',
        'source_delimiters': 'sourceDelimiters',
        'target': 'target',
        'target_delimiters': 'targetDelimiters',
        'source_span': 'sourceSpan',
        'target_span': 'targetSpan',
        'similarity': 'similarity',
        'memory_id': 'memory_id'
    }

    def __init__(self, source=None, source_delimiters=None, target=None, target_delimiters=None, source_span=None, target_span=None, similarity=None, memory_id=None, local_vars_configuration=None):  # noqa: E501
        """LexiconEntryExamples - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._source = None
        self._source_delimiters = None
        self._target = None
        self._target_delimiters = None
        self._source_span = None
        self._target_span = None
        self._similarity = None
        self._memory_id = None
        self.discriminator = None

        if source is not None:
            self.source = source
        if source_delimiters is not None:
            self.source_delimiters = source_delimiters
        if target is not None:
            self.target = target
        if target_delimiters is not None:
            self.target_delimiters = target_delimiters
        if source_span is not None:
            self.source_span = source_span
        if target_span is not None:
            self.target_span = target_span
        if similarity is not None:
            self.similarity = similarity
        if memory_id is not None:
            self.memory_id = memory_id

    @property
    def source(self):
        """Gets the source of this LexiconEntryExamples.  # noqa: E501

        The source string.  # noqa: E501

        :return: The source of this LexiconEntryExamples.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this LexiconEntryExamples.

        The source string.  # noqa: E501

        :param source: The source of this LexiconEntryExamples.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def source_delimiters(self):
        """Gets the source_delimiters of this LexiconEntryExamples.  # noqa: E501

        A format string that indicates, for each word, if the source word should be preceded by a space.   # noqa: E501

        :return: The source_delimiters of this LexiconEntryExamples.  # noqa: E501
        :rtype: list[str]
        """
        return self._source_delimiters

    @source_delimiters.setter
    def source_delimiters(self, source_delimiters):
        """Sets the source_delimiters of this LexiconEntryExamples.

        A format string that indicates, for each word, if the source word should be preceded by a space.   # noqa: E501

        :param source_delimiters: The source_delimiters of this LexiconEntryExamples.  # noqa: E501
        :type: list[str]
        """

        self._source_delimiters = source_delimiters

    @property
    def target(self):
        """Gets the target of this LexiconEntryExamples.  # noqa: E501

        The target string  # noqa: E501

        :return: The target of this LexiconEntryExamples.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this LexiconEntryExamples.

        The target string  # noqa: E501

        :param target: The target of this LexiconEntryExamples.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def target_delimiters(self):
        """Gets the target_delimiters of this LexiconEntryExamples.  # noqa: E501

        A format string that indicates, for each word, if the target word should be preceded by a space.   # noqa: E501

        :return: The target_delimiters of this LexiconEntryExamples.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_delimiters

    @target_delimiters.setter
    def target_delimiters(self, target_delimiters):
        """Sets the target_delimiters of this LexiconEntryExamples.

        A format string that indicates, for each word, if the target word should be preceded by a space.   # noqa: E501

        :param target_delimiters: The target_delimiters of this LexiconEntryExamples.  # noqa: E501
        :type: list[str]
        """

        self._target_delimiters = target_delimiters

    @property
    def source_span(self):
        """Gets the source_span of this LexiconEntryExamples.  # noqa: E501


        :return: The source_span of this LexiconEntryExamples.  # noqa: E501
        :rtype: LexiconEntrySourceSpan
        """
        return self._source_span

    @source_span.setter
    def source_span(self, source_span):
        """Sets the source_span of this LexiconEntryExamples.


        :param source_span: The source_span of this LexiconEntryExamples.  # noqa: E501
        :type: LexiconEntrySourceSpan
        """

        self._source_span = source_span

    @property
    def target_span(self):
        """Gets the target_span of this LexiconEntryExamples.  # noqa: E501


        :return: The target_span of this LexiconEntryExamples.  # noqa: E501
        :rtype: LexiconEntryTargetSpan
        """
        return self._target_span

    @target_span.setter
    def target_span(self, target_span):
        """Sets the target_span of this LexiconEntryExamples.


        :param target_span: The target_span of this LexiconEntryExamples.  # noqa: E501
        :type: LexiconEntryTargetSpan
        """

        self._target_span = target_span

    @property
    def similarity(self):
        """Gets the similarity of this LexiconEntryExamples.  # noqa: E501


        :return: The similarity of this LexiconEntryExamples.  # noqa: E501
        :rtype: float
        """
        return self._similarity

    @similarity.setter
    def similarity(self, similarity):
        """Sets the similarity of this LexiconEntryExamples.


        :param similarity: The similarity of this LexiconEntryExamples.  # noqa: E501
        :type: float
        """

        self._similarity = similarity

    @property
    def memory_id(self):
        """Gets the memory_id of this LexiconEntryExamples.  # noqa: E501

        A unique Memory identifier. If this identifier is missing, then the term comes from the generic concordance.   # noqa: E501

        :return: The memory_id of this LexiconEntryExamples.  # noqa: E501
        :rtype: float
        """
        return self._memory_id

    @memory_id.setter
    def memory_id(self, memory_id):
        """Sets the memory_id of this LexiconEntryExamples.

        A unique Memory identifier. If this identifier is missing, then the term comes from the generic concordance.   # noqa: E501

        :param memory_id: The memory_id of this LexiconEntryExamples.  # noqa: E501
        :type: float
        """

        self._memory_id = memory_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LexiconEntryExamples):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LexiconEntryExamples):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class DocumentQuote(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'num_source_words': 'int',
        'num_words_new': 'int',
        'num_segments_new': 'int',
        'num_words_repetition': 'int',
        'num_segments_repetition': 'int',
        'bands': 'list[MatchBand]'
    }

    attribute_map = {
        'id': 'id',
        'num_source_words': 'num_source_words',
        'num_words_new': 'num_words_new',
        'num_segments_new': 'num_segments_new',
        'num_words_repetition': 'num_words_repetition',
        'num_segments_repetition': 'num_segments_repetition',
        'bands': 'bands'
    }

    def __init__(self, id=None, num_source_words=None, num_words_new=None, num_segments_new=None, num_words_repetition=None, num_segments_repetition=None, bands=None, local_vars_configuration=None):  # noqa: E501
        """DocumentQuote - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._num_source_words = None
        self._num_words_new = None
        self._num_segments_new = None
        self._num_words_repetition = None
        self._num_segments_repetition = None
        self._bands = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if num_source_words is not None:
            self.num_source_words = num_source_words
        if num_words_new is not None:
            self.num_words_new = num_words_new
        if num_segments_new is not None:
            self.num_segments_new = num_segments_new
        if num_words_repetition is not None:
            self.num_words_repetition = num_words_repetition
        if num_segments_repetition is not None:
            self.num_segments_repetition = num_segments_repetition
        if bands is not None:
            self.bands = bands

    @property
    def id(self):
        """Gets the id of this DocumentQuote.  # noqa: E501

        A unique Document identifier.  # noqa: E501

        :return: The id of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DocumentQuote.

        A unique Document identifier.  # noqa: E501

        :param id: The id of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def num_source_words(self):
        """Gets the num_source_words of this DocumentQuote.  # noqa: E501

        The number of source words in the Document.  # noqa: E501

        :return: The num_source_words of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._num_source_words

    @num_source_words.setter
    def num_source_words(self, num_source_words):
        """Sets the num_source_words of this DocumentQuote.

        The number of source words in the Document.  # noqa: E501

        :param num_source_words: The num_source_words of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._num_source_words = num_source_words

    @property
    def num_words_new(self):
        """Gets the num_words_new of this DocumentQuote.  # noqa: E501

        The number of new source words in the Document.  # noqa: E501

        :return: The num_words_new of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._num_words_new

    @num_words_new.setter
    def num_words_new(self, num_words_new):
        """Sets the num_words_new of this DocumentQuote.

        The number of new source words in the Document.  # noqa: E501

        :param num_words_new: The num_words_new of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._num_words_new = num_words_new

    @property
    def num_segments_new(self):
        """Gets the num_segments_new of this DocumentQuote.  # noqa: E501

        The number of new segments in the Document.  # noqa: E501

        :return: The num_segments_new of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._num_segments_new

    @num_segments_new.setter
    def num_segments_new(self, num_segments_new):
        """Sets the num_segments_new of this DocumentQuote.

        The number of new segments in the Document.  # noqa: E501

        :param num_segments_new: The num_segments_new of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._num_segments_new = num_segments_new

    @property
    def num_words_repetition(self):
        """Gets the num_words_repetition of this DocumentQuote.  # noqa: E501

        The number of repetition source words in the Document.  # noqa: E501

        :return: The num_words_repetition of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._num_words_repetition

    @num_words_repetition.setter
    def num_words_repetition(self, num_words_repetition):
        """Sets the num_words_repetition of this DocumentQuote.

        The number of repetition source words in the Document.  # noqa: E501

        :param num_words_repetition: The num_words_repetition of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._num_words_repetition = num_words_repetition

    @property
    def num_segments_repetition(self):
        """Gets the num_segments_repetition of this DocumentQuote.  # noqa: E501

        The number of repetition segments in the Document.  # noqa: E501

        :return: The num_segments_repetition of this DocumentQuote.  # noqa: E501
        :rtype: int
        """
        return self._num_segments_repetition

    @num_segments_repetition.setter
    def num_segments_repetition(self, num_segments_repetition):
        """Sets the num_segments_repetition of this DocumentQuote.

        The number of repetition segments in the Document.  # noqa: E501

        :param num_segments_repetition: The num_segments_repetition of this DocumentQuote.  # noqa: E501
        :type: int
        """

        self._num_segments_repetition = num_segments_repetition

    @property
    def bands(self):
        """Gets the bands of this DocumentQuote.  # noqa: E501

        A list of MatchBand objects that represent translation memory leverage statistics.  # noqa: E501

        :return: The bands of this DocumentQuote.  # noqa: E501
        :rtype: list[MatchBand]
        """
        return self._bands

    @bands.setter
    def bands(self, bands):
        """Sets the bands of this DocumentQuote.

        A list of MatchBand objects that represent translation memory leverage statistics.  # noqa: E501

        :param bands: The bands of this DocumentQuote.  # noqa: E501
        :type: list[MatchBand]
        """

        self._bands = bands

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentQuote):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DocumentQuote):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class Comment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'text': 'str',
        'annotations': 'list[Annotation]',
        'is_resolved': 'bool',
        'document_id': 'int',
        'segment_id': 'int',
        'segment_revision_id': 'int',
        'user_id': 'int',
        'created_at': 'int'
    }

    attribute_map = {
        'id': 'id',
        'text': 'text',
        'annotations': 'annotations',
        'is_resolved': 'is_resolved',
        'document_id': 'document_id',
        'segment_id': 'segment_id',
        'segment_revision_id': 'segment_revision_id',
        'user_id': 'user_id',
        'created_at': 'created_at'
    }

    def __init__(self, id=None, text=None, annotations=None, is_resolved=None, document_id=None, segment_id=None, segment_revision_id=None, user_id=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """Comment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._text = None
        self._annotations = None
        self._is_resolved = None
        self._document_id = None
        self._segment_id = None
        self._segment_revision_id = None
        self._user_id = None
        self._created_at = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if text is not None:
            self.text = text
        if annotations is not None:
            self.annotations = annotations
        if is_resolved is not None:
            self.is_resolved = is_resolved
        if document_id is not None:
            self.document_id = document_id
        if segment_id is not None:
            self.segment_id = segment_id
        if segment_revision_id is not None:
            self.segment_revision_id = segment_revision_id
        if user_id is not None:
            self.user_id = user_id
        if created_at is not None:
            self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this Comment.  # noqa: E501

        A unique number identifying the Comment.  # noqa: E501

        :return: The id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Comment.

        A unique number identifying the Comment.  # noqa: E501

        :param id: The id of this Comment.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def text(self):
        """Gets the text of this Comment.  # noqa: E501

        The comment text.  # noqa: E501

        :return: The text of this Comment.  # noqa: E501
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """Sets the text of this Comment.

        The comment text.  # noqa: E501

        :param text: The text of this Comment.  # noqa: E501
        :type: str
        """

        self._text = text

    @property
    def annotations(self):
        """Gets the annotations of this Comment.  # noqa: E501

        A list of optional Annotations.  # noqa: E501

        :return: The annotations of this Comment.  # noqa: E501
        :rtype: list[Annotation]
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this Comment.

        A list of optional Annotations.  # noqa: E501

        :param annotations: The annotations of this Comment.  # noqa: E501
        :type: list[Annotation]
        """

        self._annotations = annotations

    @property
    def is_resolved(self):
        """Gets the is_resolved of this Comment.  # noqa: E501

        Whether the Comment is resolved.  # noqa: E501

        :return: The is_resolved of this Comment.  # noqa: E501
        :rtype: bool
        """
        return self._is_resolved

    @is_resolved.setter
    def is_resolved(self, is_resolved):
        """Sets the is_resolved of this Comment.

        Whether the Comment is resolved.  # noqa: E501

        :param is_resolved: The is_resolved of this Comment.  # noqa: E501
        :type: bool
        """

        self._is_resolved = is_resolved

    @property
    def document_id(self):
        """Gets the document_id of this Comment.  # noqa: E501

        The document to which the comment belongs.  # noqa: E501

        :return: The document_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """Sets the document_id of this Comment.

        The document to which the comment belongs.  # noqa: E501

        :param document_id: The document_id of this Comment.  # noqa: E501
        :type: int
        """

        self._document_id = document_id

    @property
    def segment_id(self):
        """Gets the segment_id of this Comment.  # noqa: E501

        The individual segment to which the comment applies.  # noqa: E501

        :return: The segment_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._segment_id

    @segment_id.setter
    def segment_id(self, segment_id):
        """Sets the segment_id of this Comment.

        The individual segment to which the comment applies.  # noqa: E501

        :param segment_id: The segment_id of this Comment.  # noqa: E501
        :type: int
        """

        self._segment_id = segment_id

    @property
    def segment_revision_id(self):
        """Gets the segment_revision_id of this Comment.  # noqa: E501

        The revision of the individual segment to which the comment applies.  # noqa: E501

        :return: The segment_revision_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._segment_revision_id

    @segment_revision_id.setter
    def segment_revision_id(self, segment_revision_id):
        """Sets the segment_revision_id of this Comment.

        The revision of the individual segment to which the comment applies.  # noqa: E501

        :param segment_revision_id: The segment_revision_id of this Comment.  # noqa: E501
        :type: int
        """

        self._segment_revision_id = segment_revision_id

    @property
    def user_id(self):
        """Gets the user_id of this Comment.  # noqa: E501

        The user who created this comment.  # noqa: E501

        :return: The user_id of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Comment.

        The user who created this comment.  # noqa: E501

        :param user_id: The user_id of this Comment.  # noqa: E501
        :type: int
        """

        self._user_id = user_id

    @property
    def created_at(self):
        """Gets the created_at of this Comment.  # noqa: E501

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :return: The created_at of this Comment.  # noqa: E501
        :rtype: int
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Comment.

        Time at which the object was created. Measured in seconds since the Unix epoch.  # noqa: E501

        :param created_at: The created_at of this Comment.  # noqa: E501
        :type: int
        """

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Comment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Comment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class TranslationList(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'untokenized_source': 'str',
        'tokenized_source': 'str',
        'source_delimiters': 'list[str]',
        'translation': 'list[Translation]'
    }

    attribute_map = {
        'untokenized_source': 'untokenizedSource',
        'tokenized_source': 'tokenizedSource',
        'source_delimiters': 'sourceDelimiters',
        'translation': 'translation'
    }

    def __init__(self, untokenized_source=None, tokenized_source=None, source_delimiters=None, translation=None, local_vars_configuration=None):  # noqa: E501
        """TranslationList - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._untokenized_source = None
        self._tokenized_source = None
        self._source_delimiters = None
        self._translation = None
        self.discriminator = None

        if untokenized_source is not None:
            self.untokenized_source = untokenized_source
        if tokenized_source is not None:
            self.tokenized_source = tokenized_source
        if source_delimiters is not None:
            self.source_delimiters = source_delimiters
        if translation is not None:
            self.translation = translation

    @property
    def untokenized_source(self):
        """Gets the untokenized_source of this TranslationList.  # noqa: E501

        The untokenized source segment. Punctuation has not been separated from words.  # noqa: E501

        :return: The untokenized_source of this TranslationList.  # noqa: E501
        :rtype: str
        """
        return self._untokenized_source

    @untokenized_source.setter
    def untokenized_source(self, untokenized_source):
        """Sets the untokenized_source of this TranslationList.

        The untokenized source segment. Punctuation has not been separated from words.  # noqa: E501

        :param untokenized_source: The untokenized_source of this TranslationList.  # noqa: E501
        :type: str
        """

        self._untokenized_source = untokenized_source

    @property
    def tokenized_source(self):
        """Gets the tokenized_source of this TranslationList.  # noqa: E501

        The tokenized source segment. Punctuation has been separated from words.  # noqa: E501

        :return: The tokenized_source of this TranslationList.  # noqa: E501
        :rtype: str
        """
        return self._tokenized_source

    @tokenized_source.setter
    def tokenized_source(self, tokenized_source):
        """Sets the tokenized_source of this TranslationList.

        The tokenized source segment. Punctuation has been separated from words.  # noqa: E501

        :param tokenized_source: The tokenized_source of this TranslationList.  # noqa: E501
        :type: str
        """

        self._tokenized_source = tokenized_source

    @property
    def source_delimiters(self):
        """Gets the source_delimiters of this TranslationList.  # noqa: E501

        A format string that indicates, for each word, if the word should be preceded by a space.  # noqa: E501

        :return: The source_delimiters of this TranslationList.  # noqa: E501
        :rtype: list[str]
        """
        return self._source_delimiters

    @source_delimiters.setter
    def source_delimiters(self, source_delimiters):
        """Sets the source_delimiters of this TranslationList.

        A format string that indicates, for each word, if the word should be preceded by a space.  # noqa: E501

        :param source_delimiters: The source_delimiters of this TranslationList.  # noqa: E501
        :type: list[str]
        """

        self._source_delimiters = source_delimiters

    @property
    def translation(self):
        """Gets the translation of this TranslationList.  # noqa: E501

        A list of Translation objects.  # noqa: E501

        :return: The translation of this TranslationList.  # noqa: E501
        :rtype: list[Translation]
        """
        return self._translation

    @translation.setter
    def translation(self, translation):
        """Sets the translation of this TranslationList.

        A list of Translation objects.  # noqa: E501

        :param translation: The translation of this TranslationList.  # noqa: E501
        :type: list[Translation]
        """

        self._translation = translation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TranslationList):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TranslationList):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import lilt
from lilt.api.converter_config_api import ConverterConfigApi  # noqa: E501
from lilt.rest import ApiException


class TestConverterConfigApi(unittest.TestCase):
    """ConverterConfigApi unit test stubs"""

    def setUp(self):
        self.api = lilt.api.converter_config_api.ConverterConfigApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_converter_config(self):
        """Test case for add_converter_config

        Add Converter Config  # noqa: E501
        """
        pass

    def test_delete_converter_config(self):
        """Test case for delete_converter_config

        Delete Converter Config  # noqa: E501
        """
        pass

    def test_delete_filter_mapping(self):
        """Test case for delete_filter_mapping

        Delete Filter Mapping  # noqa: E501
        """
        pass

    def test_edit_filter_mapping(self):
        """Test case for edit_filter_mapping

        Add Filter Mapping  # noqa: E501
        """
        pass

    def test_get_converter_config_by_id(self):
        """Test case for get_converter_config_by_id

        Fetch Converter Config by Id  # noqa: E501
        """
        pass

    def test_get_converter_configs(self):
        """Test case for get_converter_configs

        List Converter Configs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class QARuleMatchesRule(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'category': 'QARuleMatchesRuleCategory',
        'description': 'str',
        'id': 'str',
        'issue_type': 'str',
        'sub_id': 'str',
        'urls': 'list[QARuleMatchesRuleUrls]'
    }

    attribute_map = {
        'category': 'category',
        'description': 'description',
        'id': 'id',
        'issue_type': 'issueType',
        'sub_id': 'subId',
        'urls': 'urls'
    }

    def __init__(self, category=None, description=None, id=None, issue_type=None, sub_id=None, urls=None, local_vars_configuration=None):  # noqa: E501
        """QARuleMatchesRule - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._category = None
        self._description = None
        self._id = None
        self._issue_type = None
        self._sub_id = None
        self._urls = None
        self.discriminator = None

        self.category = category
        self.description = description
        self.id = id
        if issue_type is not None:
            self.issue_type = issue_type
        if sub_id is not None:
            self.sub_id = sub_id
        if urls is not None:
            self.urls = urls

    @property
    def category(self):
        """Gets the category of this QARuleMatchesRule.  # noqa: E501


        :return: The category of this QARuleMatchesRule.  # noqa: E501
        :rtype: QARuleMatchesRuleCategory
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this QARuleMatchesRule.


        :param category: The category of this QARuleMatchesRule.  # noqa: E501
        :type: QARuleMatchesRuleCategory
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def description(self):
        """Gets the description of this QARuleMatchesRule.  # noqa: E501


        :return: The description of this QARuleMatchesRule.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this QARuleMatchesRule.


        :param description: The description of this QARuleMatchesRule.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and description is None:  # noqa: E501
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def id(self):
        """Gets the id of this QARuleMatchesRule.  # noqa: E501

        An rule's identifier that's unique for this language.  # noqa: E501

        :return: The id of this QARuleMatchesRule.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QARuleMatchesRule.

        An rule's identifier that's unique for this language.  # noqa: E501

        :param id: The id of this QARuleMatchesRule.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def issue_type(self):
        """Gets the issue_type of this QARuleMatchesRule.  # noqa: E501

        The Localization Quality Issue Type. This is not defined for all languages, in which case it will always be 'Uncategorized'.  # noqa: E501

        :return: The issue_type of this QARuleMatchesRule.  # noqa: E501
        :rtype: str
        """
        return self._issue_type

    @issue_type.setter
    def issue_type(self, issue_type):
        """Sets the issue_type of this QARuleMatchesRule.

        The Localization Quality Issue Type. This is not defined for all languages, in which case it will always be 'Uncategorized'.  # noqa: E501

        :param issue_type: The issue_type of this QARuleMatchesRule.  # noqa: E501
        :type: str
        """

        self._issue_type = issue_type

    @property
    def sub_id(self):
        """Gets the sub_id of this QARuleMatchesRule.  # noqa: E501

        An optional sub identifier of the rule, used when several rules are grouped.  # noqa: E501

        :return: The sub_id of this QARuleMatchesRule.  # noqa: E501
        :rtype: str
        """
        return self._sub_id

    @sub_id.setter
    def sub_id(self, sub_id):
        """Sets the sub_id of this QARuleMatchesRule.

        An optional sub identifier of the rule, used when several rules are grouped.  # noqa: E501

        :param sub_id: The sub_id of this QARuleMatchesRule.  # noqa: E501
        :type: str
        """

        self._sub_id = sub_id

    @property
    def urls(self):
        """Gets the urls of this QARuleMatchesRule.  # noqa: E501

        An optional array of URLs with a more detailed description of the error.  # noqa: E501

        :return: The urls of this QARuleMatchesRule.  # noqa: E501
        :rtype: list[QARuleMatchesRuleUrls]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """Sets the urls of this QARuleMatchesRule.

        An optional array of URLs with a more detailed description of the error.  # noqa: E501

        :param urls: The urls of this QARuleMatchesRule.  # noqa: E501
        :type: list[QARuleMatchesRuleUrls]
        """

        self._urls = urls

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QARuleMatchesRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QARuleMatchesRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "lilt"
VERSION = "0.6.5b"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Lilt REST API",
    author="Lilt REST API Support",
    author_email="support@lilt.com",
    url="https://github.com/lilt/lilt-python",
    keywords=["OpenAPI", "OpenAPI-Generator", "Lilt REST API"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the &#x60;username&#x60; and &#x60;password&#x60;.  For development, you may also pass the REST API key via the &#x60;key&#x60; query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501
    """
)



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class Connector1(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'args': 'object',
        'schedule': 'str'
    }

    attribute_map = {
        'name': 'name',
        'args': 'args',
        'schedule': 'schedule'
    }

    def __init__(self, name=None, args=None, schedule=None, local_vars_configuration=None):  # noqa: E501
        """Connector1 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._args = None
        self._schedule = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if args is not None:
            self.args = args
        if schedule is not None:
            self.schedule = schedule

    @property
    def name(self):
        """Gets the name of this Connector1.  # noqa: E501

        Name of connector.  # noqa: E501

        :return: The name of this Connector1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Connector1.

        Name of connector.  # noqa: E501

        :param name: The name of this Connector1.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def args(self):
        """Gets the args of this Connector1.  # noqa: E501

        Connector parameters.  # noqa: E501

        :return: The args of this Connector1.  # noqa: E501
        :rtype: object
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this Connector1.

        Connector parameters.  # noqa: E501

        :param args: The args of this Connector1.  # noqa: E501
        :type: object
        """

        self._args = args

    @property
    def schedule(self):
        """Gets the schedule of this Connector1.  # noqa: E501

        Cron string  # noqa: E501

        :return: The schedule of this Connector1.  # noqa: E501
        :rtype: str
        """
        return self._schedule

    @schedule.setter
    def schedule(self, schedule):
        """Sets the schedule of this Connector1.

        Cron string  # noqa: E501

        :param schedule: The schedule of this Connector1.  # noqa: E501
        :type: str
        """

        self._schedule = schedule

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Connector1):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Connector1):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lilt REST API

    The Lilt REST API enables programmatic access to the full-range of Lilt backend services including:   * Training of and translating with interactive, adaptive machine translation   * Large-scale translation memory   * The Lexicon (a large-scale termbase)   * Programmatic control of the Lilt CAT environment   * Translation memory synchronization  Requests and responses are in JSON format. The REST API only responds to HTTPS / SSL requests. ## Authentication Requests are authenticated via REST API key, which requires the Business plan.  Requests are authenticated using [HTTP Basic Auth](https://en.wikipedia.org/wiki/Basic_access_authentication). Add your REST API key as both the `username` and `password`.  For development, you may also pass the REST API key via the `key` query parameter. This is less secure than HTTP Basic Auth, and is not recommended for production use.   # noqa: E501

    The version of the OpenAPI document: v2.0
    Contact: support@lilt.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from lilt.configuration import Configuration


class Translation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'target': 'str',
        'target_with_tags': 'str',
        'align': 'str',
        'provenance': 'str',
        'score': 'float',
        'is_tm_match': 'bool',
        'target_delimiters': 'list[str]',
        'target_words': 'list[str]'
    }

    attribute_map = {
        'target': 'target',
        'target_with_tags': 'targetWithTags',
        'align': 'align',
        'provenance': 'provenance',
        'score': 'score',
        'is_tm_match': 'isTMMatch',
        'target_delimiters': 'targetDelimiters',
        'target_words': 'targetWords'
    }

    def __init__(self, target=None, target_with_tags=None, align=None, provenance=None, score=None, is_tm_match=None, target_delimiters=None, target_words=None, local_vars_configuration=None):  # noqa: E501
        """Translation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._target = None
        self._target_with_tags = None
        self._align = None
        self._provenance = None
        self._score = None
        self._is_tm_match = None
        self._target_delimiters = None
        self._target_words = None
        self.discriminator = None

        if target is not None:
            self.target = target
        if target_with_tags is not None:
            self.target_with_tags = target_with_tags
        if align is not None:
            self.align = align
        if provenance is not None:
            self.provenance = provenance
        if score is not None:
            self.score = score
        if is_tm_match is not None:
            self.is_tm_match = is_tm_match
        if target_delimiters is not None:
            self.target_delimiters = target_delimiters
        if target_words is not None:
            self.target_words = target_words

    @property
    def target(self):
        """Gets the target of this Translation.  # noqa: E501

        The target string.  # noqa: E501

        :return: The target of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Translation.

        The target string.  # noqa: E501

        :param target: The target of this Translation.  # noqa: E501
        :type: str
        """

        self._target = target

    @property
    def target_with_tags(self):
        """Gets the target_with_tags of this Translation.  # noqa: E501

        The target string with source tags projected into the target.  # noqa: E501

        :return: The target_with_tags of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._target_with_tags

    @target_with_tags.setter
    def target_with_tags(self, target_with_tags):
        """Sets the target_with_tags of this Translation.

        The target string with source tags projected into the target.  # noqa: E501

        :param target_with_tags: The target_with_tags of this Translation.  # noqa: E501
        :type: str
        """

        self._target_with_tags = target_with_tags

    @property
    def align(self):
        """Gets the align of this Translation.  # noqa: E501

        \"MT only: A whitespace delimited list of source-target alignment indices.\"   # noqa: E501

        :return: The align of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._align

    @align.setter
    def align(self, align):
        """Sets the align of this Translation.

        \"MT only: A whitespace delimited list of source-target alignment indices.\"   # noqa: E501

        :param align: The align of this Translation.  # noqa: E501
        :type: str
        """

        self._align = align

    @property
    def provenance(self):
        """Gets the provenance of this Translation.  # noqa: E501

        Positive values indicate that the word is from the Memory, with contiguous identical entries (e.g., 2 2) indicating phrase matches. Negative contiguous values indicate entries from the Lexicon. 0 indicates a word from the background data.   # noqa: E501

        :return: The provenance of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._provenance

    @provenance.setter
    def provenance(self, provenance):
        """Sets the provenance of this Translation.

        Positive values indicate that the word is from the Memory, with contiguous identical entries (e.g., 2 2) indicating phrase matches. Negative contiguous values indicate entries from the Lexicon. 0 indicates a word from the background data.   # noqa: E501

        :param provenance: The provenance of this Translation.  # noqa: E501
        :type: str
        """

        self._provenance = provenance

    @property
    def score(self):
        """Gets the score of this Translation.  # noqa: E501

        The score of the translation.  # noqa: E501

        :return: The score of this Translation.  # noqa: E501
        :rtype: float
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this Translation.

        The score of the translation.  # noqa: E501

        :param score: The score of this Translation.  # noqa: E501
        :type: float
        """

        self._score = score

    @property
    def is_tm_match(self):
        """Gets the is_tm_match of this Translation.  # noqa: E501

        TM only: If true, indicates an exact translation memory match.  # noqa: E501

        :return: The is_tm_match of this Translation.  # noqa: E501
        :rtype: bool
        """
        return self._is_tm_match

    @is_tm_match.setter
    def is_tm_match(self, is_tm_match):
        """Sets the is_tm_match of this Translation.

        TM only: If true, indicates an exact translation memory match.  # noqa: E501

        :param is_tm_match: The is_tm_match of this Translation.  # noqa: E501
        :type: bool
        """

        self._is_tm_match = is_tm_match

    @property
    def target_delimiters(self):
        """Gets the target_delimiters of this Translation.  # noqa: E501

        A format string that indicates, for each word, if the word should be preceded by a space.  # noqa: E501

        :return: The target_delimiters of this Translation.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_delimiters

    @target_delimiters.setter
    def target_delimiters(self, target_delimiters):
        """Sets the target_delimiters of this Translation.

        A format string that indicates, for each word, if the word should be preceded by a space.  # noqa: E501

        :param target_delimiters: The target_delimiters of this Translation.  # noqa: E501
        :type: list[str]
        """

        self._target_delimiters = target_delimiters

    @property
    def target_words(self):
        """Gets the target_words of this Translation.  # noqa: E501

        The target string can be constructed by suffixing each `targetDelimiters` entry with its corresponding word in `targetWords` and concatenating the constructed array. Please note that the `targetDelimiters` array has one more entry than `targetWords` array which is why the last entry in the array will be the last value of `targetDelimiters`.   # noqa: E501

        :return: The target_words of this Translation.  # noqa: E501
        :rtype: list[str]
        """
        return self._target_words

    @target_words.setter
    def target_words(self, target_words):
        """Sets the target_words of this Translation.

        The target string can be constructed by suffixing each `targetDelimiters` entry with its corresponding word in `targetWords` and concatenating the constructed array. Please note that the `targetDelimiters` array has one more entry than `targetWords` array which is why the last entry in the array will be the last value of `targetDelimiters`.   # noqa: E501

        :param target_words: The target_words of this Translation.  # noqa: E501
        :type: list[str]
        """

        self._target_words = target_words

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Translation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Translation):
            return True

        return self.to_dict() != other.to_dict()
